@@ -6,23 +6,24 @@
 #' @param posterior TRUE/FALSE value for whether the cluster parameters should be from the posterior. If false then the values are from the prior.
 #' @param m Number of auxiliary variables to use for a non-conjugate mixing distribution. Defaults to m=3. See \code{\link{ClusterComponentUpdate}} for more details on m.
 #' @param verbose Logical flag indicating whether to output the acceptance ratio for non-conjugate mixtures.
+#' @param numInitialClusters Number of clusters to initialise with.
 #' @return A Dirichlet process object that has initial cluster allocations.
 #' @export
-Initialise <- function(dpObj, posterior = TRUE, m=3, verbose=TRUE){
+Initialise <- function(dpObj, posterior = TRUE, m=3, verbose=TRUE, numInitialClusters = 1){
   UseMethod("Initialise", dpObj)
 }
 
 #' @export
-Initialise.conjugate <- function(dpObj, posterior = TRUE, m=NULL, verbose=NULL) {
+Initialise.conjugate <- function(dpObj, posterior = TRUE, m=NULL, verbose=NULL, numInitialClusters = 1) {
 
-  dpObj$clusterLabels <- rep_len(1, dpObj$n)
-  dpObj$numberClusters <- 1
-  dpObj$pointsPerCluster <- dpObj$n
+  dpObj$clusterLabels <- rep(seq_len(numInitialClusters), dpObj$n)
+  dpObj$numberClusters <- numInitialClusters
+  dpObj$pointsPerCluster <- vapply(seq_len(numInitialClusters), function(x) sum(dpObj$clusterLabels == x), numeric(1))
 
-  if (posterior) {
+  if (posterior && numInitialClusters == 1) {
     dpObj$clusterParameters <- PosteriorDraw(dpObj$mixingDistribution, dpObj$data, 1)
   } else {
-    dpObj$clusterParameters <- PriorDraw(dpObj$mixingDistribution, 1)
+    dpObj$clusterParameters <- PriorDraw(dpObj$mixingDistribution, numInitialClusters)
   }
 
   dpObj <- InitialisePredictive(dpObj)
@@ -31,7 +32,7 @@ Initialise.conjugate <- function(dpObj, posterior = TRUE, m=NULL, verbose=NULL)
 }
 
 #'@export
-Initialise.nonconjugate <- function(dpObj, posterior = TRUE, m = 3, verbose = TRUE) {
+Initialise.nonconjugate <- function(dpObj, posterior = TRUE, m = 3, verbose = TRUE, numInitialClusters=1) {
 
   # dpObj$clusterLabels <- 1:dpObj$n dpObj$numberClusters <- dpObj$n
   # dpObj$pointsPerCluster <- rep(1, dpObj$n) dpObj$clusterParameters <-
