@@ -7,15 +7,19 @@ update_concentration <- function(oldParam, n, nParams, priorParameters){
   pi2 <- n * (priorParameters[2] - log(x))
   pi1 <- pi1/(pi1 + pi2)
 
-  if (runif(1) < pi1) {
-    g1 <- rgamma(1, priorParameters[1] + nParams, priorParameters[2] - log(x))
-    new_alpha <- g1
-  } else {
-    g2 <- rgamma(1, priorParameters[1] + nParams - 1, priorParameters[2] - log(x))
-    new_alpha <- g2
-  }
+  postParams1 <- priorParameters[1] + nParams
+  postParams2 <- priorParameters[2] - log(x)
 
-  #new_alpha
+  if (runif(1) > pi1) {
+    #g1 <- rgamma(1, priorParameters[1] + nParams, priorParameters[2] - log(x))
+    #new_alpha <- g1
+    postParams1 <- postParams1 - 1
+  } #else {
+    #g2 <- rgamma(1, priorParameters[1] + nParams - 1, priorParameters[2] - log(x))
+    #new_alpha <- g2
+  #}
+
+  new_alpha <- rgamma(1, postParams1, postParams2)
   return(new_alpha)
 }
 
